@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-use v5.10;
+use 5.010;
 use URI;
 use AnyEvent::FTP::Client;
 use Term::Prompt qw( prompt );
